Epochs class
============

This page documents the :class:`pyneon.Epochs` class, which segments :class:`pyneon.Stream` or :class:`pyneon.Events` data
into epochs based on specified criteria. It also documents the helper functions :func:`pyneon.events_to_epochs_info`
and :func:`pyneon.construct_epochs_info` for creating the epochs information DataFrame.

.. autoclass:: pyneon.Epochs
    :members:

.. autofunction:: pyneon.events_to_epochs_info

.. autofunction:: pyneon.construct_epochs_info